@@ -120,7 +120,7 @@ def get_stats(
             if (use_builtin_types or use_objects):
                 _res = __convert_to_builtin(_res)
 
-            res[func_name_enum if use_objects else func_name] = _res
+            res[func_name if use_objects else func_name_enum] = _res
         except Exception as e:
             print(func_name, e)
 
